Discover Packages
github.com/vanducng/miu-db
internal
query
package
Version:
v0.2.2
Opens a new window with list of versions in this module.
Published: Jun 4, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Outcome struct {
Result any `json:"result"`
NextCursor string `json:"next_cursor,omitempty"`
RowsAffected int64 `json:"rows_affected,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.